function [y, y1] = runge(x) 
% 
% calling sequence 
%   y = runge(x) 
% 
% Input
% ------
% x  : a single point, or multiple points within [-5,5] 
%      in an array 
% 
% Output
% -------
% y  : the numerical value(s) of the Runge function (1901) 
%      at x 
% y1 : the numnercal value of the first derivative at x 
% 
% Purpose
% -------
%   used for the study of limitation with polynomial interpolation 
%   sequence as the number of the interpolation nodes increases 
% 

% Xiaobai Sun 
% Duke CS 
% for the class of Numerical Analysis 
% 

y  = 1./(1 + x.^2); 

y1 = -2 * x./y.^2 ; 


return 
  
